Package 'hubverse'

Title: Easily Install and Load the 'hubverse'
Description: A collection of packages that enables collaborative modeling exercises through a unified framework for aggregating, visualizing, and evaluating forecasts. This package is designed to make it easy to install and load multiple 'hubverse' packages in a single step. Learn more at <https://hubverse.io/>.
Authors: Li Shandross [aut, cre] (ORCID: <https://orcid.org/0009-0008-1348-1954>), Consortium of Infectious Disease Modeling Hubs [cph]
Maintainer: Li Shandross <[email protected]>
License: MIT + file LICENSE
Version: 0.0.1.0000
Built: 2026-05-15 14:19:58 UTC
Source: https://github.com/hubverse-org/hubverse

Help Index